<?php

declare(strict_types=1);

namespace Drupal\data_pipelines_elasticsearch;

use Drupal\data_pipelines\DatasetPipelineBase;
use Drupal\data_pipelines\Transform\TransformInterface;

/**
 * Elasticsearch specific data pipeline plugin class.
 */
class ElasticSearchDatasetPipeline extends DatasetPipelineBase {

  public function __construct() {
    @trigger_error(
      <<<EOT
Mappings that are defined at the top level of your pipeline will no longer take effect. Please place them under:
destinationSettings:
  elasticsearch:
    mappings:
      ...
EOT,
      E_USER_ERROR,
    );
  }

  /**
   * {@inheritdoc}
   */
  protected function getTransformPluginInstance(array $definition): ?TransformInterface {
    $definition += ['mappings' => []];
    return parent::getTransformPluginInstance($definition);
  }

  /**
   * Get the mapping for the elastic search index.
   *
   * @return array
   *   The mapping for the elastic search index.
   */
  public function getMappings(): array {
    return $this->pluginDefinition['mappings'];
  }

}
